[Groonga-commit] groonga/groonga-command at 0bd136c [fix-travis-ci-error] Rename exist to object_exist

Back to archive index

Kouhei Sutou null+****@clear*****
Wed Jan 13 17:33:53 JST 2016


Kouhei Sutou	2015-07-27 12:53:24 +0900 (Mon, 27 Jul 2015)

  New Revision: 0bd136c0801d9b52a1ff05fb5659e681ecc21eb1
  https://github.com/groonga/groonga-command/commit/0bd136c0801d9b52a1ff05fb5659e681ecc21eb1

  Message:
    Rename exist to object_exist

  Modified files:
    lib/groonga/command.rb
  Renamed files:
    lib/groonga/command/object-exist.rb
      (from lib/groonga/command/exist.rb)
    test/command/test-object-exist.rb
      (from test/command/test-exist.rb)

  Modified: lib/groonga/command.rb (+1 -1)
===================================================================
--- lib/groonga/command.rb    2015-07-24 16:19:44 +0900 (ec3b70e)
+++ lib/groonga/command.rb    2015-07-27 12:53:24 +0900 (bc4d0dd)
@@ -26,7 +26,6 @@ require "groonga/command/column-remove"
 require "groonga/command/column-rename"
 require "groonga/command/delete"
 require "groonga/command/dump"
-require "groonga/command/exist"
 require "groonga/command/get"
 require "groonga/command/io-flush"
 require "groonga/command/load"
@@ -35,6 +34,7 @@ require "groonga/command/logical-range-filter"
 require "groonga/command/logical-select"
 require "groonga/command/logical-table-remove"
 require "groonga/command/normalize"
+require "groonga/command/object-exist"
 require "groonga/command/plugin-register"
 require "groonga/command/plugin-unregister"
 require "groonga/command/range-filter"

  Renamed: lib/groonga/command/object-exist.rb (+3 -3) 89%
===================================================================
--- test/command/test-exist.rb    2015-07-24 16:19:44 +0900 (fa698d2)
+++ test/command/test-object-exist.rb    2015-07-27 12:53:24 +0900 (1e07a91)
@@ -14,19 +14,19 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-class ExistCommandTest < Test::Unit::TestCase
+class ObjectExistCommandTest < Test::Unit::TestCase
   private
-  def exist_command(pair_arguments={}, ordered_arguments=[])
-    Groonga::Command::Exist.new("exist",
-                                    pair_arguments,
-                                    ordered_arguments)
+  def object_exist_command(pair_arguments={}, ordered_arguments=[])
+    Groonga::Command::ObjectExist.new("object_exist",
+                                      pair_arguments,
+                                      ordered_arguments)
   end
 
   class ConstructorTest < self
     def test_ordered_arguments
       name = "Users"
 
-      command = exist_command({}, [name])
+      command = object_exist_command({}, [name])
       assert_equal({
                      :name => name,
                    },
@@ -36,7 +36,7 @@ class ExistCommandTest < Test::Unit::TestCase
 
   class NameTest < self
     def test_reader
-      command = exist_command(:name => "Users")
+      command = object_exist_command(:name => "Users")
       assert_equal("Users", command.name)
     end
   end
-------------- next part --------------
HTML����������������������������...
Télécharger 



More information about the Groonga-commit mailing list
Back to archive index
--- lib/groonga/command/exist.rb    2015-07-24 16:19:44 +0900 (0232677)
+++ lib/groonga/command/object-exist.rb    2015-07-27 12:53:24 +0900 (7485f14)
@@ -18,11 +18,11 @@ require "groonga/command/base"
 
 module Groonga
   module Command
     # A command class that represents `exist` command.
     #
     # @since 1.1.3
-    class Exist < Base
-      Command.register("exist", self)
+    class ObjectExist < Base
+      Command.register("object_exist", self)
 
       class << self
         def parameter_names
@@ -18,11 +18,11 @@ require "groonga/command/base"
 module Groonga
   module Command
-    # A command class that represents `exist` command.
+    # A command class that represents `object_exist` command.
     #
     # @since 1.1.3

  Renamed: test/command/test-object-exist.rb (+7 -7) 74%
===================================================================